@@ -166,96 +166,121 @@ class Foreperson:
         if 'visit' in keys:
             self.data_source.origin.id = recipe['visit']['visit id']
             if 'date' in recipe['visit'].keys():
-                self.data_source.origin.date = datetime.datetime.strptime(str(recipe['visit']['date']), '%Y-%m-%d')
+                self.data_source.origin.date = datetime.datetime.strptime(
+                    str(recipe['visit']['date']), '%Y-%m-%d')
                 self.data_source.origin.year = self.data_source.origin.date.year
             if 'local contact' in recipe['visit'].keys():
-                self.data_source.origin.contact = recipe['visit']['local contact']
+                self.data_source.origin.contact = recipe[
+                    'visit']['local contact']
             if 'user' in recipe['visit'].keys():
                 self.creator.name = recipe['visit']['user']
             if 'affiliation' in recipe['visit'].keys():
                 self.creator.affiliation = recipe['visit']['user affiliation']
         else:
-            raise ValueError("No visit given in {}. You must at least give a visit id".format(yaml_file))
+            raise ValueError(
+                "No visit given in {}. "\
+                "You must at least give a visit id".format(yaml_file))
         # Populate informatio from the information section
         if 'instrument' in keys:
             self.data_source.experiment.instrument = recipe['instrument']
             self.reduction.parser = function_map[recipe['instrument']]
         # Populate cropping information
         if 'crop' in keys:
-            self.reduction.crop_function = function_map[recipe['crop']['method']]
+            self.reduction.crop_function = function_map[
+                recipe['crop']['method']]
             if 'kwargs' in recipe['crop']:
                 self.reduction.crop_kwargs = recipe['crop']['kwargs']
         # Populate background subtraction method
         if 'background' in keys:
-            self.reduction.bkg_function = function_map[recipe['background']['method']]
+            self.reduction.bkg_function = function_map[
+                recipe['background']['method']]
             if 'kwargs' in recipe['background']:
                 self.reduction.bkg_kwargs = recipe['background']['kwargs']
 
         # Populate the setup information
         if 'setup' in keys:
             if 'dcd normalisation' in recipe['setup'].keys():
-                self.reduction.dcd_normalisation = recipe['setup']['dcd normalisation']
-                self.data_source.links = {'instrument reference': 'doi:10.1107/S0909049512009272'}
+                self.reduction.dcd_normalisation = recipe[
+                    'setup']['dcd normalisation']
+                self.data_source.links = {
+                    'instrument reference': 'doi:10.1107/S0909049512009272'}
             if 'sample size' in recipe['setup'].keys():
-                self.reduction.sample_size = make_tuple(recipe['setup']['sample size'])
+                self.reduction.sample_size = make_tuple(recipe[
+                    'setup']['sample size'])
                 try:
                     _ = len(self.reduction.sample_size)
-                    self.reduction.sample_size = ufloat(self.reduction.sample_size[0], self.reduction.sample_size[1])
+                    self.reduction.sample_size = ufloat(
+                        self.reduction.sample_size[0],
+                        self.reduction.sample_size[1])
                 except TypeError:
                     pass
             else:
-                raise ValueError("No sample size given in setup of {}.".format(yaml_file))
+                raise ValueError("No sample size given in setup of {}.".format(
+                    yaml_file))
             if 'beam width' in recipe['setup'].keys():
-                self.reduction.beam_width = make_tuple(recipe['setup']['beam width'])
+                self.reduction.beam_width = make_tuple(recipe[
+                    'setup']['beam width'])
                 try:
                     _ = len(self.reduction.beam_width)
-                    self.reduction.beam_width = ufloat(self.reduction.beam_width[0], self.reduction.beam_width[1])
+                    self.reduction.beam_width = ufloat(
+                        self.reduction.beam_width[0],
+                        self.reduction.beam_width[1])
                 except TypeError:
                     pass
             else:
-                raise ValueError("No beam width given in setup of {}.".format(yaml_file))
+                raise ValueError("No beam width given in setup of {}.".format(
+                    yaml_file))
             if 'theta_axis' in recipe['setup'].keys():
-                self.data_source.experiment.measurement.theta_axis_name = recipe['setup']['theta_axis']
+                self.data_source.experiment.measurement.theta_axis_name = (
+                    recipe['setup']['theta_axis'])
             if 'q axis' in recipe['setup'].keys():
-                self.data_source.experiment.measurement.q_axis_name = recipe['setup']['q axis']
+                self.data_source.experiment.measurement.q_axis_name = (
+                    recipe['setup']['q axis'])
             if 'transpose' in recipe['setup'].keys():
-                self.data_source.experiment.measurement.transpose = recipe['setup']['transpose']
+                self.data_source.experiment.measurement.transpose = (
+                    recipe['setup']['transpose'])
                 if self.data_source.experiment.measurement.transpose:
                     self.data_source.experiment.measurement.qz_dimension = 0
                     self.data_source.experiment.measurement.qxy_dimension = 1
             if 'pixel_max' in recipe['setup'].keys():
-                self.data_source.experiment.measurement.pixel_max = recipe['setup']['pixel_max']
+                self.data_source.experiment.measurement.pixel_max = recipe[
+                    'setup']['pixel_max']
             if 'hot_pixel_max' in recipe['setup'].keys():
-                self.data_source.experiment.measurement.hot_pixel_max = recipe['setup']['hot_pixel_max']
+                self.data_source.experiment.measurement.hot_pixel_max = recipe[
+                    'setup']['hot_pixel_max']
         else:
             raise ValueError("No setup given in {}.".format(yaml_file))
         if 'output_columns' in keys:
             if recipe['output_columns'] == 3:
-                self.data = Data(columns=['Qz / Aa^-1', 'RQz', 'sigma RQz, standard deviation'])
+                self.data = Data(
+                    columns=[
+                        'Qz / Aa^-1', 'RQz', 'sigma RQz, standard deviation'])
         if 'rebin' in keys:
             if 'n qvectors' in recipe['rebin'].keys():
                 self.data.n_qvectors = recipe['rebin']['n qvectors']
-            elif 'min' in recipe['rebin'].keys() and 'max' in recipe['rebin'].keys() and 'step' in recipe['rebin'].keys():
+            elif 'min' in recipe['rebin'].keys() and 'max' in recipe[
+                'rebin'].keys() and 'step' in recipe['rebin'].keys():
                 self.data.q_min = recipe['rebin']['min']
                 self.data.q_max = recipe['rebin']['max']
                 self.data.q_step = recipe['rebin']['step']
                 if 'shape' in recipe['rebin'].keys():
                     self.data.q_shape = recipe['rebin']['shape']
             else:
-                raise ValueError("Please define parameters of rebin in {}.".format(yaml_file))
+                raise ValueError("Please define parameters of "\
+                                 "rebin in {}.".format(yaml_file))
         else:
             self.data.rebin=False
 
 
-def reduce(run_numbers, yaml_file, directory='/dls/{}/data/{}/{}/', title='Unknown'):
+def reduce(run_numbers, yaml_file, directory='/dls/{}/data/{}/{}/',
+           title='Unknown'):
     """
     The runner that parses the yaml file and performs the data reduction.
 
     run_numbers (:py:attr:`list` of :py:attr:`int`): Reflectometry scans that
         make up the profile.
     yaml_file (:py:attr:`str`): File path to instruction set.
-    metadata (:py:attr:`dict`): If metadata should be included in the outpuit
-        file, pass this as a :py:attr:`dict`.
+    directory (:py:attr:`str`): Outline for directory path.
     title (:py:attr:`str`): A title for the experiment.
     """
     the_boss = Foreperson(run_numbers, yaml_file, directory, title)
@@ -267,12 +292,11 @@ def reduce(run_numbers, yaml_file, directory='/dls/{}/data/{}/{}/', title='Unkno
     print('File Parsing')
     print("-" * 10)
     refl = refl_data.Profile(files_to_reduce, the_boss.reduction.parser,
-                             the_boss.data_source.experiment.measurement.q_axis_name,
-                             the_boss.data_source.experiment.measurement.theta_axis_name,
-                             None, 0,
-                             the_boss.data_source.experiment.measurement.pixel_max,
-                             the_boss.data_source.experiment.measurement.hot_pixel_max,
-                             the_boss.data_source.experiment.measurement.transpose)
+         the_boss.data_source.experiment.measurement.q_axis_name,
+         the_boss.data_source.experiment.measurement.theta_axis_name,
+         None, 0, the_boss.data_source.experiment.measurement.pixel_max,
+         the_boss.data_source.experiment.measurement.hot_pixel_max,
+         the_boss.data_source.experiment.measurement.transpose)
     print("-" * 10)
     print('Cropping')
     print("-" * 10)
@@ -288,8 +312,9 @@ def reduce(run_numbers, yaml_file, directory='/dls/{}/data/{}/{}/', title='Unkno
     print("-" * 10)
     print('Estimating Resolution Function')
     print("-" * 10)
-    refl.resolution_function(the_boss.data_source.experiment.measurement.qz_dimension,
-                             progress=True)
+    refl.resolution_function(
+        the_boss.data_source.experiment.measurement.qz_dimension,
+        progress=True)
     the_boss.reduction.data_state.resolution = 'estimated'
 
     print("-" * 10)
@@ -300,7 +325,8 @@ def reduce(run_numbers, yaml_file, directory='/dls/{}/data/{}/{}/', title='Unkno
             the_boss.reduction.dcd_normalisation, the_boss.reduction.parser)
         refl.qdcd_normalisation(itp)
         the_boss.reduction.data_state.dcd = 'normalised'
-    refl.footprint_correction(the_boss.reduction.beam_width, the_boss.reduction.sample_size)
+    refl.footprint_correction(
+        the_boss.reduction.beam_width, the_boss.reduction.sample_size)
     refl.transmission_normalisation()
     the_boss.reduction.data_state.transmission = 'normalised'
     refl.concatenate()
@@ -322,14 +348,21 @@ def reduce(run_numbers, yaml_file, directory='/dls/{}/data/{}/{}/', title='Unkno
                                      the_boss.data.q_step))
         the_boss.reduction.data_state.rebinned = the_boss.data.q_shape
 
-    the_boss.data_source.experiment.measurement.q_range = [str(refl.q.min()), str(refl.q.max())]
+    the_boss.data_source.experiment.measurement.q_range = [
+        str(refl.q.min()), str(refl.q.max())]
     try:
         _ = the_boss.data.column_4
         data = np.array([refl.q, refl.R, refl.dR, refl.dq]).T
-        np.savetxt(the_boss.directory_path + '/processing/XRR_' + run_numbers[0] + '.dat', data, header='{}\n 1 2 3 4'.format(dump(vars(the_boss))))
+        np.savetxt(
+            (the_boss.directory_path + '/processing/XRR_{}.dat'.format(
+                run_numbers[0])), data,
+             header='{}\n 1 2 3 4'.format(dump(vars(the_boss))))
     except:
         data = np.array([refl.q, refl.R, refl.dR]).T
-        np.savetxt(the_boss.directory_path + '/processing/XRR_' + run_numbers[0] + '.dat', data, header='{}\n 1 2 3'.format(dump(vars(the_boss))))
+        np.savetxt(
+            (the_boss.directory_path + '/processing/XRR_{}.dat'.format(
+                run_numbers[0])), data,
+             header='{}\n 1 2 3'.format(dump(vars(the_boss))))
 
     print("-" * 10)
     print('Reduced Data Stored in Processing Directory')
